#
# spec file for package python-pyudev
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-pyudev
Version:        0.16.1
Release:        15.5
Summary:        Udev bindings for Python
License:        LGPL-2.1+
Group:          Development/Libraries/Python
Url:            http://pyudev.readthedocs.org/
Source0:        http://pypi.python.org/packages/source/p/pyudev/pyudev-%{version}.tar.gz
BuildRequires:  libudev-devel
BuildRequires:  python-Sphinx
BuildRequires:  python-devel
BuildRequires:  python-setuptools
# Testsuite BuildRequires:
BuildRequires:  python-mock
BuildRequires:  python-nose
BuildRequires:  python-py
BuildRequires:  python-pytest
# pyudev was last used in KDE:Unstable:Playground (pyudev-0.8)
Provides:       pyudev = %{version}
Obsoletes:      pyudev < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
A Python binding to libudev, the hardware management library and service found
in modern linux systems.

%prep
%setup -q -n pyudev-%{version}
# Disable intersphinx and issuetracker, we don't want to access the web during doc build:
sed -i -e "s|'sphinx.ext.intersphinx',\\?||" -e "s|'sphinxcontrib.issuetracker',\\?||" doc/conf.py

%build
python setup.py build
python setup.py build_sphinx
rm build/sphinx/html/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

#TODO: fix
#%%check
#nosetests

%files
%defattr(-,root,root,-)
%doc CHANGES.rst COPYING README.rst build/sphinx/html/
%{python_sitelib}/*

%changelog
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Nov 20 2012 saschpe@suse.de
- Build HTML documentation
- Fix SLE_11_SP2 build (not noarch)
* Sun Nov 18 2012 asterios.dramis@gmail.com
- Update to version 0.16.1:
  * #53: Fix source distribution
  * #54: Fix typo in test
  From version 0.16:
  * Remove :meth:`pyudev.Monitor.from_socket`.
  * Deprecate :meth:`pyudev.Device.traverse()` in favor of
    :attr:`pyudev.Device.ancestors`.
  * #47: Deprecate :meth:`pyudev.Monitor.receive_device` in favor of
    :attr:`pyudev.Monitor.poll`.
  * #47: Deprecate :attr:`pyudev.Monitor.enable_receiving` in favor of
    :attr:`pyudev.Monitor.start`.
  * #47: Deprecate :attr:`pyudev.Monitor.__iter__` in favor of explicit looping
    or :class:`pyudev.MonitorObserver`.
  * #49: Deprecate ``event_handler`` to :class:`pyudev.MonitorObserver` in
    favour of ``callback`` argument.
  * #46: Continuously test pyudev on Travis-CI.
  * Add :attr:`pyudev.Device.ancestors`.
  * Add :attr:`pyudev.Device.action`.
  * #10: Add :attr:`pyudev.Device.sequence_number`.
  * #47: Add :meth:`pyudev.Monitor.poll`.
  * #47: Add :attr:`pyudev.Monitor.started`.
  * #49: Add ``callback`` argument to :class:`pyudev.Monitor`.
  * :meth:`pyudev.Monitor.start` can be called repeatedly.
  * #45: Get rid of 2to3
  * #43: Fix test failures on Python 2.6
  * Fix signature in declaration of ``udev_monitor_set_receive_buffer_size``.
  * #44: Test wrapped signatures with help of ``gccxml``.
  * Fix compatibility with udev 183 and newer in :class:`pyudev.Context`.
  * :meth:`pyudev.MonitorObserver.stop` can be called from the observer thread.
- Removed python-setuptools and added python-distribute as build requirement.
* Sat Mar 10 2012 asterios.dramis@gmail.com
- Update to version 0.15:
  * #20: :meth:`pyudev.Monitor.filter_by()` and
    :meth:`pyudev.Monitor.filter_by_tag()` can be called after
    :meth:`pyudev.Monitor.enable_receiving()` now
  * #20: Added :meth:`~pyudev.Monitor.remove_filter()`
  * :class:`pyudev.MonitorObserver` calls
    :meth:`pyudev.Monitor.enable_receiving()` now when started.
  * #40: Added user guide to the documentation
  * #39: Added :meth:`pyudev.Device.from_device_file()`
  * :data:`errno.EINVAL` from underlying libudev functions causes
    :exc:`~exceptions.ValueError` instead of
    :exc:`~exceptions.EnvironmentError` now.
* Sat Feb 18 2012 asterios.dramis@gmail.com
- Update to version 0.14:
  * Documentation now hosted at http://pyudev.readthedocs.org
  * #37: Added :class:`pyudev.wx.WxUDevMonitorObserver` for wxPython
  * Added :class:`pyudev.MonitorObserver`
  * Added :attr:`pyudev.glib.GUDevMonitorObserver.enabled`,
    :attr:`pyudev.pyqt4.QUDevMonitorObserver.enabled` and
    :attr:`pyudev.pyside.QUDevMonitorObserver.enabled`
* Sun Nov  6 2011 asterios.dramis@gmail.com
- Update to version 0.13:
  * #36: Added :meth:`pyudev.Monitor.set_receive_buffer_size` (thanks to Rémi
    Rérolle)
  * #34: :class:`pyudev.Device.tags` returns a :class:`pyudev.Tags` object now
  * Added :meth:`pyudev.Enumerator.match_parent`
  * Added ``parent`` keyword argument to :meth:`pyudev.Enumerator.match()`
  * Removed :meth:`pyudev.Enumerator.match_children` in favour of
    :meth:`pyudev.Enumerator.match_parent`
  * :attr:`pyudev.Device.children` requires udev version 172 now
  * #31: Added :meth:`pyudev.Enumerator.match_attribute`
  * Added ``nomatch`` argument to :meth:`pyudev.Enumerator.match_subsystem` and
    :meth:`pyudev.Enumerator.match_attribute`
* Wed Aug 31 2011 asterios.dramis@gmail.com
- Update to version 0.12:
  * #32: Fixed memory leak
  * #33: Fixed Python 3 support for :mod:`pyudev.glib`
  * Fixed license header in :mod:`pyudev._compat`
- Spec file updates.
  * Changed License: to LGPL-2.1+.
  * Minor other updates.
* Sun Aug 28 2011 asterios.dramis@gmail.com
- Update to version 0.11:
  * #30: Added :attr:`pyudev.Device.sys_number`
  * #29: Added :meth:`pyudev.Device.from_device_number` and
    :attr:`pyudev.Device.device_number`
  * Officially support PyPy now
  From 0.10:
  * Added :attr:`pyudev.__version_info__`
  * Added :attr:`pyudev.Device.device_type`
  * :class:`pyudev.Context`, :class:`pyudev.Enumerator`, :class:`pyudev.Device`
    and :class:`pyudev.Monitor` can now directly be passed to
    :mod:`ctypes`-wrapped functions
  * #24: Added :attr:`pyudev.Context.run_path`
  From 0.9:
  * #21: Added :meth:`pyudev.Device.find_parent`
  * #22: Added :meth:`pyudev.Monitor.filter_by_tag`
  * Added :attr:`pyudev.Context.log_priority` to control internal UDev logging
  * Improve error reporting, if libudev is missing
- Spec file updates:
  * Changed package name to python-pyudev.
  * Changed License: to LGPL-2.1.
  * Updated Url:.
  * Added Provides/Obsoletes entries for pyudev.
  * Build the package as noarch.
  * Minor other updates.
* Tue Feb  8 2011 tittiatcoke@gmail.com
- Initial Package (version 0.8).
